-- Add your NPCs in this file
-- NPC ID have to be a number!

---------------------------
-- Description of values --
---------------------------

-- name            - STRING - Name of the NPC
-- imagePath       - STRING - Path to the image for NPC
-- deathSound      - STRING - Path to the sound file which will be played when NPC dies
-- speed           - NUMBER - Moving speed of NPC (pixels per frame)
-- rotationSpeed   - NUMBER - Rotation speed of NPC (degree per frame)
-- behaviorType    - NUMBER - Type of NPC's behavior (0 - melee NPC, 1 - range NPC)
-- attackCoolDown  - NUMBER - Time between attacks of the NPC (in seconds)
-- health          - NUMBER - Health of an NPC
-- damage          - NUMBER - Damage dealt to a player by an NPC
-- hitbox          - NUMBER - Hitbox for an NPC (pixels) (will be centred) (one number for X and Y (square))
-- bulletNum	   - NUMBER - Amount of bullets fired by an NPC (has to be in even melee npcs)
-- wander		   - NUMBER - Whether or not an NPC wanders (0 for not wandering, and 1 for wandering)
-- dropMoney 	   - NUMBER - Controls whether or not an NPC drops money upon dying (0 for no drop, 1 for $100, 2 for $500, and 3 for $1000)
-- team			   - NUMBER - Controls which players an NPC shoots (0 no allegiance (attack everyone), 1 terrorists (attack cts), 2 counter-terrorists (attack ts))

-- -- --> You will only need this values if NPC's behavior type is 1 (range) <-- -- --
-- bulletLength    - NUMBER - Length of a bullet of NPC
-- bulletSpreading - NUMBER - Bullet spreading
-- bulletOffSet    - NUMBER - Offset for a starting point of a bullet (pixels)
-- bulletSound     - STRING - Path to the sound file which will be played when NPC will shoot (path is relative to sfx folder)

-- -- --> You will only need this value if NPC's behavior type is 0 (melee) <-- -- --
-- slashSound      - STRING - Path to the sound file which will be played when NPC will attack (path is relative to sfx folder)

-- NOTE: STRING values has to be inside of quotes ("STRING" or 'STRING')

-------------
-- Pattern --
--[[---------
cnpc.list = {
	[<NPC ID>] = {
		name = "<NAME>";
		imagePath = "<PATH>";
		speed = <SPEED>;
		...
	};
	
	[<NPC ID>] = {
		name = "<NAME>";
		imagePath = "<PATH>";
		speed = <SPEED>;
		...
	};
}
---------]]--

cnpc.list = {
	[1] = {
		name = 'Counter-Terrorist with Knife';
		imagePath = 'gfx/cnpc/ct1knife.bmp<m>';
		deathSound = 'player/die1.wav';
		speed = 3.5;
		rotationSpeed = 14;
		behaviorType = 0;
		attackCoolDown = 0.33;
		health = 100;
		damage = 45;
		hitbox = 32;
		bulletNum = 1;
		wander = 1;
		dropMoney = 1;
		team = 2;
		
		slashSound = 'weapons/knife_slash.wav';

	};
	
	[2] = {
		name = 'Terrorist with Knife';
		imagePath = 'gfx/cnpc/t1knife.bmp<m>';
		deathSound = 'player/die1.wav';
		speed = 3.5;
		rotationSpeed = 14;
		behaviorType = 0;
		attackCoolDown = 0.33;
		health = 100;
		damage = 45;
		hitbox = 32;
		bulletNum = 1;
		wander = 1;
		dropMoney = 1;
		team = 1;
		
		slashSound = 'weapons/knife_slash.wav';

	};
	
	[3] = {
		name = 'Counter-Terrorist with USP';
		imagePath = 'gfx/cnpc/ct1usp.bmp<m>';
		deathSound = 'player/die1.wav';
		speed = 3;
		rotationSpeed = 7;
		behaviorType = 1;
		attackCoolDown = 0.46;
		health = 100;
		damage = 24;
		hitbox = 32;
		bulletNum = 1;
		wander = 1;
		dropMoney = 1;
		team = 2;

		bulletLength = 15000;
		bulletSpreading = 0;
		bulletOffset = 16;
		bulletSound = 'weapons/usp.wav';

	};
	
	[4] = {
		name = 'Terrorist with Glock';
		imagePath = 'gfx/cnpc/t1glock.bmp<m>';
		deathSound = 'player/die1.wav';
		speed = 3;
		rotationSpeed = 7;
		behaviorType = 1;
		attackCoolDown = 0.46;
		health = 100;
		damage = 21;
		hitbox = 32;
		bulletNum = 1;
		wander = 1;
		dropMoney = 1;
		team = 1;

		bulletLength = 15000;
		bulletSpreading = 0;
		bulletOffset = 16;
		bulletSound = 'weapons/glock18.wav';

	};
	
	[5] = {
		name = 'Counter-Terrorist with XM1014';
		imagePath = 'gfx/cnpc/ct1xm1014.bmp<m>';
		deathSound = 'player/die1.wav';
		speed = 2;
		rotationSpeed = 7;
		behaviorType = 1;
		attackCoolDown = 0.33;
		health = 100;
		damage = 22;
		hitbox = 32;
		bulletNum = 5;
		wander = 1;
		dropMoney = 1;
		team = 2;

		bulletLength = 15000;
		bulletSpreading = 10;
		bulletOffset = 16;
		bulletSound = 'weapons/xm1014.wav';

	};
	
	[6] = {
		name = 'Terrorist with M3';
		imagePath = 'gfx/cnpc/t1m3.bmp<m>';
		deathSound = 'player/die1.wav';
		speed = 2;
		rotationSpeed = 7;
		behaviorType = 1;
		attackCoolDown = 0.94;
		health = 100;
		damage = 26;
		hitbox = 32;
		bulletNum = 5;
		wander = 1;
		dropMoney = 1;
		team = 1;

		bulletLength = 15000;
		bulletSpreading = 10;
		bulletOffset = 16;
		bulletSound = 'weapons/m3.wav';

	};
	
	[7] = {
		name = 'Counter-Terrorist with P90';
		imagePath = 'gfx/cnpc/ct1p90.bmp<m>';
		deathSound = 'player/die1.wav';
		speed = 2;
		rotationSpeed = 7;
		behaviorType = 1;
		attackCoolDown = 0.07;
		health = 100;
		damage = 11;
		hitbox = 32;
		bulletNum = 1;
		wander = 1;
		dropMoney = 1;
		team = 2;

		bulletLength = 15000;
		bulletSpreading = 3;
		bulletOffset = 16;
		bulletSound = 'weapons/p90.wav';

	};
	
	[8] = {
		name = 'Terrorist with Mac 10';
		imagePath = 'gfx/cnpc/t1mac10.bmp<m>';
		deathSound = 'player/die1.wav';
		speed = 2.7;
		rotationSpeed = 7;
		behaviorType = 1;
		attackCoolDown = 0.07;
		health = 100;
		damage = 9;
		hitbox = 32;
		bulletNum = 1;
		wander = 1;
		dropMoney = 1;
		team = 1;

		bulletLength = 15000;
		bulletSpreading = 3;
		bulletOffset = 16;
		bulletSound = 'weapons/mac10.wav';

	};
	
	[9] = {
		name = 'Counter-Terrorist with M4A1';
		imagePath = 'gfx/cnpc/ct1m4a1.bmp<m>';
		deathSound = 'player/die1.wav';
		speed = 2;
		rotationSpeed = 7;
		behaviorType = 1;
		attackCoolDown = 0.12;
		health = 100;
		damage = 22;
		hitbox = 32;
		bulletNum = 1;
		wander = 1;
		dropMoney = 1;
		team = 2;

		bulletLength = 15000;
		bulletSpreading = 2;
		bulletOffset = 16;
		bulletSound = 'weapons/m4a1.wav';

	};
	
	[10] = {
		name = 'Terrorist with AK-47';
		imagePath = 'gfx/cnpc/t1ak47.bmp<m>';
		deathSound = 'player/die1.wav';
		speed = 2;
		rotationSpeed = 7;
		behaviorType = 1;
		attackCoolDown = 0.12;
		health = 100;
		damage = 22;
		hitbox = 32;
		bulletNum = 1;
		wander = 1;
		dropMoney = 1;
		team = 1;

		bulletLength = 15000;
		bulletSpreading = 3;
		bulletOffset = 16;
		bulletSound = 'weapons/ak47.wav';

	};
	
	[11] = {
		name = 'Counter-Terrorist with Scout';
		imagePath = 'gfx/cnpc/ct1scout.bmp<m>';
		deathSound = 'player/die1.wav';
		speed = 2.2;
		rotationSpeed = 7;
		behaviorType = 1;
		attackCoolDown = 0.94;
		health = 100;
		damage = 50;
		hitbox = 32;
		bulletNum = 1;
		wander = 1;
		dropMoney = 1;
		team = 2;

		bulletLength = 15000;
		bulletSpreading = 0;
		bulletOffset = 16;
		bulletSound = 'weapons/scout.wav';

	};
	
	[12] = {
		name = 'Terrorist with AWP';
		imagePath = 'gfx/cnpc/t1awp.bmp<m>';
		deathSound = 'player/die1.wav';
		speed = 1;
		rotationSpeed = 7;
		behaviorType = 1;
		attackCoolDown = 1.88;
		health = 100;
		damage = 65;
		hitbox = 32;
		bulletNum = 1;
		wander = 1;
		dropMoney = 1;
		team = 1;

		bulletLength = 15000;
		bulletSpreading = 0;
		bulletOffset = 16;
		bulletSound = 'weapons/awp.wav';

	};
	
	[13] = {
		name = 'Counter-Terrorist with M134';
		imagePath = 'gfx/cnpc/ct1m134.bmp<m>';
		deathSound = 'player/die1.wav';
		speed = 0.5;
		rotationSpeed = 7;
		behaviorType = 1;
		attackCoolDown = 0.07;
		health = 100;
		damage = 13;
		hitbox = 32;
		bulletNum = 1;
		wander = 1;
		dropMoney = 1;
		team = 2;

		bulletLength = 15000;
		bulletSpreading = 5;
		bulletOffset = 16;
		bulletSound = 'weapons/m134.wav';

	};
	
	[14] = {
		name = 'Terrorist with M249';
		imagePath = 'gfx/cnpc/t1m249.bmp<m>';
		deathSound = 'player/die1.wav';
		speed = 1;
		rotationSpeed = 7;
		behaviorType = 1;
		attackCoolDown = 0.07;
		health = 100;
		damage = 15;
		hitbox = 32;
		bulletNum = 1;
		wander = 1;
		dropMoney = 1;
		team = 1;

		bulletLength = 15000;
		bulletSpreading = 8;
		bulletOffset = 16;
		bulletSound = 'weapons/m249.wav';

	}
}